@@ -306,14 +306,14 @@ Returns the sum of the weights we apply to each day in the requested period.
 =cut
 
 sub weighted_days_in_period {
-    my ($self, $begin, $end) = @_;
+    my ($self, $begin, $end, $include) = @_;
 
     $end = $end->truncate_to_day;
     my $current = $begin->truncate_to_day->plus_time_interval('1d');
     my $days    = 0.0;
 
     while (not $current->is_after($end)) {
-        $days += $self->weight_on($current);
+        $days += $self->weight_on($current, $include);
         $current = $current->plus_time_interval('1d');
     }
 
@@ -328,7 +328,7 @@ Returns our closed weight for days when the market is closed.
 =cut
 
 sub weight_on {
-    my ($self, $date) = @_;
+    my ($self, $date, $include) = @_;
 
     my $calendar = $self->build_trading_calendar;
     my $base = $self->build_asset;
@@ -352,6 +352,31 @@ sub weight_on {
         $weight = min($weight, $currency_weight);
     }
 
+    # We are adjusting our volatility based on market events for these dates.
+    # These HACKS will be removed after 2016-06-23
+    my ($jpy_announcement_date, $euro_announcement_date);
+    if ($include) {
+        $jpy_announcement_date = Date::Utility->new('2016-06-15');
+        $euro_announcement_date = Date::Utility->new('2016-06-22');
+    } else {
+        $jpy_announcement_date = Date::Utility->new('2016-06-16');
+        $euro_announcement_date = Date::Utility->new('2016-06-23');
+    }
+
+    if ($self->underlying_config->symbol =~ /JPY/ and $date->truncate_to_day->epoch == $jpy_announcement_date->epoch) {
+        return 11;
+    }
+
+    if ($date->truncate_to_day->epoch == $euro_announcement_date->minus_time_interval('1d')->epoch) {
+        return 10 if ($self->underlying_config->symbol =~ /GBP/);
+        return 5 if ($self->underlying_config->symbol =~ /EUR/);
+    }
+
+    if ($date->truncate_to_day->epoch == $euro_announcement_date->epoch) {
+        return 25 if ($self->underlying_config->symbol =~ /GBP/);
+        return 12 if ($self->underlying_config->symbol =~ /EUR/);
+    }
+
     return $weight;
 }
 
